@@ -1,12 +1,13 @@
 from typing import Any, Dict, List, Optional, Set
 
-from dagster import Permissive, check, resource
+import dagster._check as check
+from dagster import Permissive, resource
 from dagster.utils.merger import merge_dicts
 
 from ..dbt_resource import DbtResource
 from .constants import CLI_COMMON_FLAGS_CONFIG_SCHEMA, CLI_COMMON_OPTIONS_CONFIG_SCHEMA
 from .types import DbtCliOutput
-from .utils import execute_cli
+from .utils import execute_cli, parse_manifest, parse_run_results, remove_run_results
 
 
 class DbtCliResource(DbtResource):
@@ -28,12 +29,14 @@ class DbtCliResource(DbtResource):
         ignore_handled_error: bool,
         target_path: str,
         logger: Optional[Any] = None,
+        docs_url: Optional[str] = None,
     ):
         self._default_flags = default_flags
         self._executable = executable
         self._warn_error = warn_error
         self._ignore_handled_error = ignore_handled_error
         self._target_path = target_path
+        self._docs_url = docs_url
         super().__init__(logger)
 
     @property
@@ -86,6 +89,7 @@ class DbtCliResource(DbtResource):
             warn_error=self._warn_error,
             ignore_handled_error=self._ignore_handled_error,
             target_path=self._target_path,
+            docs_url=self._docs_url,
         )
 
     def compile(
@@ -207,6 +211,19 @@ class DbtCliResource(DbtResource):
         """
         return self.cli("ls", select=select, models=models, exclude=exclude, **kwargs)
 
+    def build(self, select: Optional[List[str]] = None, **kwargs) -> DbtCliOutput:
+        """
+        Run the ``build`` command on a dbt project. kwargs are passed in as additional parameters.
+
+        Args:
+            select (List[str], optional): the models/resources to include in the run.
+
+        Returns:
+            DbtCliOutput: An instance of :class:`DbtCliOutput<dagster_dbt.DbtCliOutput>` containing
+                parsed log output as well as the contents of run_results.json (if applicable).
+        """
+        return self.cli("build", select=select, **kwargs)
+
     def freshness(self, select: Optional[List[str]] = None, **kwargs) -> DbtCliOutput:
         """
         Run the ``source snapshot-freshness`` command on a dbt project. kwargs are passed in as additional parameters.
@@ -250,6 +267,38 @@ class DbtCliResource(DbtResource):
 
         return self.cli(f"run-operation {macro}", args=args, **kwargs)
 
+    def get_run_results_json(self, **kwargs) -> Optional[Dict[str, Any]]:
+        """
+        Get a parsed version of the run_results.json file for the relevant dbt project.
+
+        Returns:
+            Dict[str, Any]: dictionary containing the parsed contents of the manifest json file
+                for this dbt project.
+        """
+        project_dir = kwargs.get("project_dir", self.default_flags["project-dir"])
+        target_path = kwargs.get("target_path", self._target_path)
+        return parse_run_results(project_dir, target_path)
+
+    def remove_run_results_json(self, **kwargs):
+        """
+        Remove the run_results.json file from previous runs (if it exists).
+        """
+        project_dir = kwargs.get("project_dir", self.default_flags["project-dir"])
+        target_path = kwargs.get("target_path", self._target_path)
+        remove_run_results(project_dir, target_path)
+
+    def get_manifest_json(self, **kwargs) -> Optional[Dict[str, Any]]:
+        """
+        Get a parsed version of the manifest.json file for the relevant dbt project.
+
+        Returns:
+            Dict[str, Any]: dictionary containing the parsed contents of the manifest json file
+                for this dbt project.
+        """
+        project_dir = kwargs.get("project_dir", self.default_flags["project-dir"])
+        target_path = kwargs.get("target_path", self._target_path)
+        return parse_manifest(project_dir, target_path)
+
 
 @resource(
     config_schema=Permissive(
@@ -266,7 +315,7 @@ def dbt_cli_resource(context) -> DbtCliResource:
     """This resource defines a dbt CLI interface.
 
     To configure this resource, we recommend using the `configured
-    <https://docs.dagster.io/overview/configuration#configured>`_ method.
+    <https://docs.dagster.io/concepts/configuration/configured>`_ method.
 
     Examples:
 
@@ -314,4 +363,5 @@ def dbt_cli_resource(context) -> DbtCliResource:
         ignore_handled_error=context.resource_config["ignore_handled_error"],
         target_path=context.resource_config["target_path"],
         logger=context.log,
+        docs_url=context.resource_config.get("docs_url"),
     )
